@@ -46,7 +46,7 @@ sub generic_handler {
 
 sub time_handler {
     my @r = generic_handler(@_);
-    return undef unless @r;
+    return undef unless $r[0];
     my $timef = $_[0]->{__RAI}->time_format;
     map { $_ = strftime( $timef, localtime str2time($_->value) ) } @r 
         if $timef;
